Learn R Programming

readepi (version 1.0.4)

sormas_get_diseases: Get the list of disease names from a SORMAS instance

Description

Get the list of disease names from a SORMAS instance

Usage

sormas_get_diseases(login)

Value

A vector of the list of disease names in a SORMAS instance

Arguments

login

A list with the user's authentication details

Examples

Run this code
if (FALSE) {
  # establish the connection to the SORMAS system
  sormas_login <- login(
    type = "sormas",
    from = "https://demo.sormas.org/sormas-rest",
    user_name = "SurvSup",
    password = "Lk5R7JXeZSEc"
  )
  disease_names <- sormas_get_diseases(
    login = sormas_login
  )
}

Run the code above in your browser using DataLab